@@ -696,12 +696,11 @@ tinyplot.default = function(
 
   # catch for adding to existing facet plot
   if (!is.null(facet) && add) {
-    if (Sys.getenv("POSITRON") == 1 && interactive()) warning(
-      "Positron IDE detected.\n",
-      "Adding layers to a faceted tinyplot in Positron leads to known alignment errors. Please see:\n",
-      "https://github.com/posit-dev/positron/issues/7316"
+    recordGraphics(
+      par(get_saved_par(when = "after")),
+      list = list(),
+      env = getNamespace('tinyplot')
     )
-    par(get_saved_par(when = "after"))
   }
 
   # Capture deparsed expressions early, before x, y and by are evaluated
@@ -1349,11 +1348,13 @@ tinyplot.default = function(
           dots = dots,
           type = type,
           x_by = x_by,
+          by_continuous = by_continuous,
           iby = ii,
           ifacet = i,
           facet_by = facet_by,
           data_facet = idata,
           ngrps = ngrps,
+          nfacets = nfacets,
           flip = flip,
           type_info = type_info,
           facet_window_args = facet_window_args
@@ -1364,8 +1365,14 @@ tinyplot.default = function(
   
   if (!add) {
     # save end pars for possible recall later
-    apar = par(no.readonly = TRUE)
-    set_saved_par(when = "after", apar)
+    recordGraphics(
+      {
+        apar = par(no.readonly = TRUE)
+        set_saved_par(when = "after", apar)
+      },
+      list = list(), 
+      env = getNamespace('tinyplot')
+    )
   }
 
 }
