@@ -4,6 +4,9 @@
 #'   are modified versions of histograms or mosaic plots, and particularly
 #'   useful for visualizing factor variables. Note that [`tinyplot`] defaults
 #'   to `type_spineplot()` if `y` is a factor variable.
+#' @param xlevels,ylevels a character or numeric vector specifying the ordering of the
+#'   levels of the `x` and `y` variables (if character) or the corresponding indexes
+#'   (if numeric) for the plot.
 #' @inheritParams graphics::spineplot
 #' @examples
 #' # "spineplot" type convenience string
@@ -47,7 +50,13 @@
 #'   type = type_spineplot(weights = ttnc$Freq),
 #'   palette = "Dark 2", facet.args = list(nrow = 1), axes = "t"
 #' )
-#' 
+#'
+#' # Reorder x and y variable categories either by their character levels or numeric indexes
+#' tinyplot(
+#'   Survived ~ Sex, facet = ~ Class, data = ttnc,
+#'   type = type_spineplot(weights = ttnc$Freq, xlevels = c("Female", "Male"), ylevels = 2:1)
+#' )
+#'
 #' # Note: It's possible to use "by" on its own (without faceting), but the
 #' # overlaid result isn't great. We will likely overhaul this behaviour in a
 #' # future version of tinyplot...
@@ -56,10 +65,10 @@
 #' )
 #' 
 #' @export
-type_spineplot = function(breaks = NULL, tol.ylab = 0.05, off = NULL, ylevels = NULL, col = NULL, xaxlabels = NULL, yaxlabels = NULL, weights = NULL) {
+type_spineplot = function(breaks = NULL, tol.ylab = 0.05, off = NULL, xlevels = NULL, ylevels = NULL, col = NULL, xaxlabels = NULL, yaxlabels = NULL, weights = NULL) {
   col = col
   out = list(
-    data = data_spineplot(off = off, breaks = breaks, ylevels = ylevels, xaxlabels = xaxlabels, yaxlabels = yaxlabels, weights = weights),
+    data = data_spineplot(off = off, breaks = breaks, xlevels = xlevels, ylevels = ylevels, xaxlabels = xaxlabels, yaxlabels = yaxlabels, weights = weights),
     draw = draw_spineplot(tol.ylab = tol.ylab, off = off, col = col, xaxlabels = xaxlabels, yaxlabels = yaxlabels),
     name = "spineplot"
   )
@@ -68,7 +77,7 @@ type_spineplot = function(breaks = NULL, tol.ylab = 0.05, off = NULL, ylevels =
 }
 
 #' @importFrom grDevices nclass.Sturges
-data_spineplot = function(off = NULL, breaks = NULL, ylevels = ylevels, xaxlabels = NULL, yaxlabels = NULL, weights = NULL) {
+data_spineplot = function(off = NULL, breaks = NULL, xlevels = xlevels, ylevels = ylevels, xaxlabels = NULL, yaxlabels = NULL, weights = NULL) {
     fun = function(
       datapoints,
       by = NULL, col = NULL, bg = NULL, palette = NULL,
@@ -114,7 +123,6 @@ data_spineplot = function(off = NULL, breaks = NULL, ylevels = ylevels, xaxlabel
 
         ## process y variable
         if (!is.factor(datapoints$y)) datapoints$y = factor(datapoints$y)
-        # if (!is.null(ylevels)) datapoints$y = factor(datapoints$y, levels = if(is.numeric(ylevels)) levels(datapoints$y)[ylevels] else ylevels)
         if (is.null(ylim)) ylim = c(0, 1)
 
         ## adjust facet margins
@@ -125,12 +133,20 @@ data_spineplot = function(off = NULL, breaks = NULL, ylevels = ylevels, xaxlabel
         x_by = identical(datapoints$x, datapoints$by)
         y_by = identical(datapoints$y, datapoints$by)
         
+        x.categorical = is.factor(datapoints$x)
+        if (!is.null(xlevels) && x.categorical) {
+          xlevels = if(is.numeric(xlevels)) levels(datapoints$x)[xlevels] else xlevels
+          if (any(is.na(xlevels)) || !all(xlevels %in% levels(datapoints$x))) warning("not all 'xlevels' correspond to levels of 'x'")
+          datapoints$x = factor(datapoints$x, levels = xlevels)
+          if (x_by) datapoints$by = datapoints$x
+        }
         if (!is.null(ylevels)) {
-          datapoints$y = factor(datapoints$y, levels = if(is.numeric(ylevels)) levels(datapoints$y)[ylevels] else ylevels)
+          ylevels = if(is.numeric(ylevels)) levels(datapoints$y)[ylevels] else ylevels
+          if (any(is.na(ylevels)) || !all(ylevels %in% levels(datapoints$y))) warning("not all 'ylevels' correspond to levels of 'y'")
+          datapoints$y = factor(datapoints$y, levels = ylevels)
           if (y_by) datapoints$by = datapoints$y
         }
         
-        x.categorical = is.factor(datapoints$x)
         x = datapoints$x
         y = datapoints$y
         
