@@ -7,18 +7,13 @@
 .onLoad = function(libname, pkgname) {
   # https://stackoverflow.com/questions/12598242/global-variables-in-packages-in-r
   # https://stackoverflow.com/questions/49056642/r-how-to-make-variable-available-to-namespace-at-loading-time?noredirect=1&lq=1
-  tnypltptns = parent.env(environment())
-  assign(".tinyplot_env", new.env(), envir = tnypltptns)
-  .tpar = new.env()
-
-  assign(".tpar", .tpar, envir = tnypltptns)
-
+  init_environment()
   init_tpar()
-
-  assign(".saved_par_before", NULL, envir = get(".tinyplot_env", envir = parent.env(environment())))
-  assign(".saved_par_after", NULL, envir = get(".tinyplot_env", envir = parent.env(environment())))
-  assign(".saved_par_first", NULL, envir = get(".tinyplot_env", envir = parent.env(environment())))
-  assign(".last_call", NULL, envir = get(".tinyplot_env", envir = parent.env(environment())))
+  set_environment_variable(".saved_par_before", NULL)
+  set_environment_variable(".saved_par_after", NULL)
+  set_environment_variable(".saved_par_first", NULL)
+  set_environment_variable(".last_call", NULL)
+  set_environment_variable(".tpar_hooks", NULL)
 
   globalVariables(c(
     "add",
@@ -43,6 +38,7 @@
     "flip",
     "frame.plot",
     "has_legend",
+    "iby",
     "ifacet",
     "nfacet_cols",
     "nfacet_rows",
